/**
 * Sharp IR sensor uses SharpIR library
 * https://github.com/guillaume-rico/SharpIR
 * 
 * Display uses U8g2lib
 * https://github.com/olikraus/u8g2
 * 
 * Example based on https://www.makerguides.com/sharp-gp2y0a21yk0f-ir-distance-sensor-arduino-tutorial/
 * 
 */

// Include libraries:
#include <SharpIR.h>
#include <U8g2lib.h>

// Define sensor model GP2Y0A21YK0F and input pin:
#define IRPin A0
#define model 1080

// Create a new instance of the SharpIR class:
SharpIR mySensor = SharpIR(IRPin, model);

// display setup:
// software i2c:
//U8X8_SSD1306_128X64_NONAME_SW_I2C u8x8(7, 8, U8X8_PIN_NONE);
// hardware i2c:
U8X8_SSD1306_128X64_NONAME_HW_I2C display(U8X8_PIN_NONE);

char buf[10]; // text buffer; to be able to use draw2x2String to show the value

void setup() {
  Serial.begin(9600); // start serial port output, check for same speed at Serial Monitor

  // initialize display:
  display.begin();
  display.setPowerSave(0);

  display.setFont(u8x8_font_pxplusibmcgathin_f);
  display.drawString(0,0,"Optical");
  display.drawString(0,1,"sensor");
  display.draw2x2String(0,3,"Dist.:");
}

void loop() {
  unsigned int distance = mySensor.distance(); // read distance from sensor
  Serial.print("Dist.: ");
  Serial.println(distance);
  
  // display value on the display in a large (2x2) font:
  snprintf(buf, 10, "%3d", distance); // put value of count into string buffer; %3d means we have 3 decimal places (because our value is always between 0 - 999)
  display.draw2x2String(0,6,buf);

  delay(500); // wait half a second
}
